"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.IsCurrent = void 0;
var _command = require("../command.js");
/**
 * IsCurrent command.
 */
class IsCurrent extends _command.Command {
  /**
   * Description.
   */
  static description = 'Check package is installed and current.';

  /**
   * Examples.
   */
  static examples = [];

  /**
   * Flags.
   */
  static flags = {
    help: _command.Flags.help({
      char: 'h'
    })
  };

  /**
   * Arguments.
   */
  static args = {
    package: _command.Args.string({
      name: 'package',
      required: true,
      description: 'Package ID.'
    })
  };

  /**
   * Handler.
   */
  async run() {
    const {
      args
    } = await this.parse(IsCurrent);
    const m = this._manager();
    const installed = await m.isInstalled(args.package);
    if (!installed) {
      throw new Error('Package is not installed');
    }
    const current = await m.isCurrent(args.package);
    if (!current) {
      throw new Error('Package is not current');
    }
    this.log('installed');
  }
}
exports.IsCurrent = IsCurrent;
var _default = exports.default = IsCurrent;
//# sourceMappingURL=is-current.js.map