import { Command as CommandBase, Help, Flags, Args, run } from '@oclif/core';
import { Manager, IPackageInstalled } from '@shockpkg/core';
import { ProgressCallback } from './progress.ts';
export { Help, Flags, Args, run };
/**
 * Command object.
 */
export declare abstract class Command extends CommandBase {
    /**
     * Init function.
     *
     * @returns Return data.
     */
    init(): Promise<any>;
    /**
     * Custom error handler function.
     *
     * @param err Error value.
     * @returns Return data if present.
     */
    catch(err: Error): Promise<any>;
    /**
     * Get the update interval.
     *
     * @returns Update interval.
     */
    protected _updateInterval(): number;
    /**
     * Check if the shell is interactive.
     *
     * @returns True if interactive shell, else false.
     */
    protected _isInteractive(): boolean;
    /**
     * Transfer seconds human readable.
     *
     * @param ms Miliseconds passed or null.
     * @returns Formatted string.
     */
    protected _transferSecondsHuman(ms: number | null): string;
    /**
     * Transfer bytes human readable.
     *
     * @param size Byte size.
     * @returns Formatted string.
     */
    protected _transferBytesHuman(size: number): string;
    /**
     * Init data transfer progress output function.
     *
     * @returns Progress update callback function.
     */
    protected _transferProgressOutputInit(): ProgressCallback;
    /**
     * Clear data transfer progress output after.
     */
    protected _transferProgressOutputAfter(): void;
    /**
     * Run an async function with a manager instance.
     *
     * @returns Manager instance..
     */
    protected _manager(): Manager;
    /**
     * Install events for reporting install progress.
     *
     * @param manager Manager instance.
     * @param reason Install reason.
     */
    protected _installEvents(manager: Manager, reason: string): void;
    /**
     * Count install report categories.
     *
     * @param report Report list.
     * @returns Report counts.
     */
    protected _installReportCounts(report: IPackageInstalled[]): {
        installed: number;
        skipped: number;
    };
}
