import { Command, Flags } from "../command.mjs";

/**
 * Cleanup command.
 */
export class Cleanup extends Command {
  /**
   * Description.
   */
  static description = 'Cleanup temporary files and obsolete packages.';

  /**
   * Examples.
   */
  static examples = [];

  /**
   * Flags.
   */
  static flags = {
    help: Flags.help({
      char: 'h'
    })
  };

  /**
   * Arguments.
   */
  static args = {};

  /**
   * Handler.
   */
  async run() {
    await this.parse(Cleanup);
    const m = this._manager();
    m.eventPackageCleanupBefore.on(e => {
      this.log(e.package);
    });
    m.eventPackageCleanupAfter.on(e => {
      // Should not normally happen, but possible.
      if (!e.removed) {
        this.warn(`nothing to remove for: ${e.package}`);
      }
    });
    await m.cleanup();
  }
}
export default Cleanup;
//# sourceMappingURL=cleanup.mjs.map