import { Command, Flags, Args, Help } from "../command.mjs";

/**
 * Help command.
 */
export class HelpCommand extends Command {
  /**
   * Description.
   */
  static description = 'Show CLI help.';

  /**
   * Examples.
   */
  static examples = [];

  /**
   * Flags.
   */
  static flags = {
    recursive: Flags.boolean({
      description: 'Include all child commands in output.',
      char: 'r'
    })
  };

  /**
   * Arguments.
   */
  static args = {
    command: Args.string({
      name: 'command',
      required: false,
      description: 'Command to show help for.'
    })
  };

  /**
   * Strict mode.
   */
  static strict = false;

  /**
   * Handler.
   */
  async run() {
    const {
      flags,
      argv
    } = await this.parse(HelpCommand);
    const help = new Help(this.config, {
      all: flags.recursive
    });
    await help.showHelp(argv);
  }
}
export default HelpCommand;
//# sourceMappingURL=help.mjs.map