import { Command, Flags, Args } from "../command.mjs";

/**
 * Install command.
 */
export class Install extends Command {
  /**
   * Description.
   */
  static description = 'Install packages.';

  /**
   * Examples.
   */
  static examples = [];

  /**
   * Flags.
   */
  static flags = {
    help: Flags.help({
      char: 'h'
    })
  };

  /**
   * Arguments.
   */
  static args = {
    packages: Args.string({
      name: 'packages',
      required: true,
      description: 'List of packages to be installed.'
    })
  };

  /**
   * Allow variable length arguments.
   */
  static strict = false;

  /**
   * Handler.
   */
  async run() {
    const {
      argv
    } = await this.parse(Install);
    const m = this._manager();
    this._installEvents(m, 'install');
    const report = [];
    for (const pkg of argv) {
      // eslint-disable-next-line no-await-in-loop
      const install = await m.install(pkg);
      report.push({
        // eslint-disable-next-line no-await-in-loop
        package: await m.packageByUnique(pkg),
        install
      });
    }
    const {
      installed,
      skipped
    } = this._installReportCounts(report);
    this.log('');
    this.log(`installed: ${installed}`);
    this.log(`skipped: ${skipped}`);
  }
}
export default Install;
//# sourceMappingURL=install.mjs.map