import { Command, Flags, Args } from "../command.mjs";

/**
 * IsCurrent command.
 */
export class IsCurrent extends Command {
  /**
   * Description.
   */
  static description = 'Check package is installed and current.';

  /**
   * Examples.
   */
  static examples = [];

  /**
   * Flags.
   */
  static flags = {
    help: Flags.help({
      char: 'h'
    })
  };

  /**
   * Arguments.
   */
  static args = {
    package: Args.string({
      name: 'package',
      required: true,
      description: 'Package ID.'
    })
  };

  /**
   * Handler.
   */
  async run() {
    const {
      args
    } = await this.parse(IsCurrent);
    const m = this._manager();
    const installed = await m.isInstalled(args.package);
    if (!installed) {
      throw new Error('Package is not installed');
    }
    const current = await m.isCurrent(args.package);
    if (!current) {
      throw new Error('Package is not current');
    }
    this.log('installed');
  }
}
export default IsCurrent;
//# sourceMappingURL=is-current.mjs.map