import { Command, Flags, Args } from "../command.mjs";

/**
 * IsInstalled command.
 */
export class IsInstalled extends Command {
  /**
   * Description.
   */
  static description = 'Check package is installed.';

  /**
   * Examples.
   */
  static examples = [];

  /**
   * Flags.
   */
  static flags = {
    help: Flags.help({
      char: 'h'
    })
  };

  /**
   * Arguments.
   */
  static args = {
    package: Args.string({
      name: 'package',
      required: true,
      description: 'Package ID.'
    })
  };

  /**
   * Handler.
   */
  async run() {
    const {
      args
    } = await this.parse(IsInstalled);
    const m = this._manager();
    const installed = await m.isInstalled(args.package);
    if (!installed) {
      throw new Error('Package is not installed');
    }
    this.log('installed');
  }
}
export default IsInstalled;
//# sourceMappingURL=is-installed.mjs.map