import { Command, Flags, Args } from "../command.mjs";

/**
 * IsObsolete command.
 */
export class IsObsolete extends Command {
  /**
   * Description.
   */
  static description = 'Check package is obsolete.';

  /**
   * Examples.
   */
  static examples = [];

  /**
   * Flags.
   */
  static flags = {
    help: Flags.help({
      char: 'h'
    })
  };

  /**
   * Arguments.
   */
  static args = {
    package: Args.string({
      name: 'package',
      required: true,
      description: 'Package ID.'
    })
  };

  /**
   * Handler.
   */
  async run() {
    const {
      args
    } = await this.parse(IsObsolete);
    const m = this._manager();
    const installed = await m.isInstalled(args.package);
    if (!installed) {
      throw new Error('Package is not installed');
    }
    const obsolete = await m.isObsolete(args.package);
    if (!obsolete) {
      throw new Error('Package is not obsolete');
    }
    this.log('obsolete');
  }
}
export default IsObsolete;
//# sourceMappingURL=is-obsolete.mjs.map