import { Command, Flags, Args } from "../command.mjs";

/**
 * Remove command.
 */
export class Remove extends Command {
  /**
   * Description.
   */
  static description = 'Remove packages.';

  /**
   * Examples.
   */
  static examples = [];

  /**
   * Flags.
   */
  static flags = {
    help: Flags.help({
      char: 'h'
    })
  };

  /**
   * Arguments.
   */
  static args = {
    packages: Args.string({
      name: 'packages',
      required: true,
      description: 'List of packages to be removed.'
    })
  };

  /**
   * Allow variable length arguments.
   */
  static strict = false;

  /**
   * Handler.
   */
  async run() {
    const {
      argv
    } = await this.parse(Remove);
    const m = this._manager();
    for (const pkg of argv) {
      this.log(pkg);
      // eslint-disable-next-line no-await-in-loop
      const removed = await m.remove(pkg);
      if (!removed) {
        this.warn(`nothing to remove for: ${pkg}`);
      }
    }
  }
}
export default Remove;
//# sourceMappingURL=remove.mjs.map