/**
 * Integer division with remainder.
 *
 * @param v Value.
 * @param d Divisor.
 * @returns Integer divided and remainder.
 */
export function divmod(v, d) {
  return [Math.floor(v / d), v % d];
}

/**
 * Get environment variable value.
 *
 * @param name Variable name.
 * @returns String value or null.
 */
export function env(name) {
  // eslint-disable-next-line no-process-env
  return process.env[name] ?? null;
}

/**
 * Get environment variable as a boolean value.
 *
 * @param name Variable name.
 * @returns Boolean value.
 */
export function envBool(name) {
  const v = env(name);
  if (v) {
    if (/^(1|true|yes)$/i.test(v)) {
      return true;
    }
    if (/^(0|false|no)$/i.test(v)) {
      return false;
    }
  }
  return null;
}

/**
 * Check if the environment variable value is true.
 *
 * @param name Variable name.
 * @returns Boolean value.
 */
export function envTrue(name) {
  return envBool(name) === true;
}

/**
 * Check if the environment variable value is false.
 *
 * @param name Variable name.
 * @returns Boolean value.
 */
export function envFalse(name) {
  return envBool(name) === false;
}

/**
 * Get environment variable as a number.
 *
 * @param name Variable name.
 * @returns Number value.
 */
export function envNumber(name) {
  const str = env(name);
  return str ? +str : null;
}

/**
 * Get environment variable as a number.
 *
 * @param name Variable name.
 * @returns Number value.
 */
export function envInteger(name) {
  const num = envNumber(name);
  if (num === 0) {
    return num;
  }
  return num && Number.isInteger(num) ? num : null;
}
//# sourceMappingURL=util.mjs.map